Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(405)

Unified Diff: base/debug/trace_event_impl.h

Issue 369703003: Reduce usage of MessageLoopProxy in base/ (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: base/debug/trace_event_impl.h
diff --git a/base/debug/trace_event_impl.h b/base/debug/trace_event_impl.h
index e5a6dbd71f9b09ed6a7c3f82da41ffe0df80f703..309cdeac4ec905bd2da6a35fd41881d0b8f60441 100644
--- a/base/debug/trace_event_impl.h
+++ b/base/debug/trace_event_impl.h
@@ -59,6 +59,7 @@ namespace base {
class WaitableEvent;
class MessageLoop;
+class SequencedTaskRunner;
namespace debug {
@@ -718,7 +719,7 @@ class BASE_EXPORT TraceLog {
ThreadLocalBoolean thread_is_in_trace_event_;
// Contains the message loops of threads that have had at least one event
// added into the local event buffer. Not using MessageLoopProxy because we
// need to know the life time of the message loops.
hash_set<MessageLoop*> thread_message_loops_;
@@ -729,7 +730,7 @@ class BASE_EXPORT TraceLog {
// Set when asynchronous Flush is in progress.
OutputCallback flush_output_callback_;
- scoped_refptr<MessageLoopProxy> flush_message_loop_proxy_;
+ scoped_refptr<SequencedTaskRunner> flush_task_runner_;
subtle::AtomicWord generation_;
DISALLOW_COPY_AND_ASSIGN(TraceLog);
@@ -718,7 +719,7 @@ class BASE_EXPORT TraceLog {
ThreadLocalBoolean thread_is_in_trace_event_;
// Contains the message loops of threads that have had at least one event
- // added into the local event buffer. Not using MessageLoopProxy because we
+ // added into the local event buffer. Not using TaskRunners because we
// need to know the life time of the message loops.
hash_set<MessageLoop*> thread_message_loops_;

Powered by Google App Engine
This is Rietveld 408576698